% MAKE_CONDITIONS Preparse the randomised experimental conditions
%
% condition = make_conditions(ngames, nid, strategy)
%
% Author Agamemnon Krasoulis
% agamemnon.krasoulis@gmail.com
%
% Inputs
%    ngames: 	number of games against each type of opponent
%    nid:      	number of possible different types of opponents
%    strategy:	strategy levels used for each opponent
% Outputs
%    condition: matrix containing the randomised conditions
%                   dim1: games
%                   dim2: col1: Opponent's ID, col2: Opponent's strategy
%
% Example: conditions = make_conditions(3, 4, [1, 3, 5])
%
% Modifications
% 04/04/14 AK First Created

function condition = make_conditions(ngames, nid, strategy)
if nargin<3
    if nargin < 2
        if nargin < 1
            ngames = 3;
        end
        nid = 4;
    end
    strategy = [1; 3; 5]; % Cooperation levels
end

if isrow(strategy)
    strategy = strategy';
end

ids = (1:1:nid)';   % ID vector
idsRand = ids(randperm(numel(ids)));
strategyNew = repmat(strategy, ceil((nid*ngames)/numel(strategy)), 1); % THIS IS WRONG AND NEEDS FIXED!!!
for j = 1:1:nid
    condition((j-1)*ngames+1:j*ngames,1) = idsRand(j); % ID
    stratTemp = strategyNew((j-1)*ngames+1:j*ngames);
    condition((j-1)*ngames+1:j*ngames,2) = stratTemp(randperm(numel(stratTemp)));
end
end % EOF